@@ -163,6 +163,10 @@ class Clusterer:
         for n,inference_dataset in enumerate(inference_datasets):
 
             self._cluster(n,inference_dataset,patch_shape_coords_df)
+            if hasattr(self,'_N_clusters_found'):
+
+                print('Found {} cluster in dataset given as input {}'-format(self._N_clusters_found,n))
+
 
         print('>----------------<',end='\r')
 
@@ -187,6 +191,7 @@ class Clusterer:
         cluster_model.fit(X)
         labels = cluster_model.labels_
         df.loc[:,'label'] = labels
+        self._N_clusters_found = len(list(set(labels)))
         self.trace.__setattr__(self.output_dataset[n],df)
 
     def read(self,name=None,save_as='csv'):
@@ -413,6 +418,9 @@ class Clusterer_HDBSCAN:
         for n, inference_dataset in enumerate(inference_datasets):
 
             self._cluster(n, inference_dataset, patch_shape_coords_df)
+            if hasattr(self,'_N_clusters_found'):
+
+                print('Found {} cluster in dataset given as input {}'-format(self._N_clusters_found,n))
 
         if self.save_model:
 
@@ -457,6 +465,7 @@ class Clusterer_HDBSCAN:
 
         labels = [np.argmax(x) for x in soft_clusters]
         df.loc[:,'label'] = labels
+        self._N_clusters_found = len(list(set(labels)))
         self.trace.__setattr__(self.output_dataset[n], df)
 
     def _save_model(self):
